==> scummvm_2.8.0+dfsg.orig.tar.xz: scummvm-2.8.0/doc/docportal/conf.py <==
# Configuration file for the Sphinx documentation builder.
#
# This file only contains a selection of the most common options. For a full
# list see the documentation:
# https://www.sphinx-doc.org/en/master/usage/configuration.html

# -- Path setup --------------------------------------------------------------

# If extensions (or modules to document with autodoc) are in another directory,
# add these directories to sys.path here. If the directory is relative to the
# documentation root, use os.path.abspath to make it absolute, like shown here.
#
# import os
# import sys
# sys.path.insert(0, os.path.abspath('.'))


# -- Project information -----------------------------------------------------

project = 'ScummVM Documentation'
copyright = '2020-2023, CadiH'
author = 'CadiH'


# -- General configuration ---------------------------------------------------

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
# ones.

import sphinx_rtd_theme

extensions = [

    "sphinx_rtd_theme",
    "sphinx_panels",
    "sphinx_mdinclude"
]
extensions.append('sphinx_tabs.tabs')
souce_suffix = ['.rst','.md']

# Add any paths that contain templates here, relative to this directory.
templates_path = ['_templates']

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
# This pattern also affects html_static_path and html_extra_path.
exclude_patterns = ['_build', 'Thumbs.db', '.DS_Store', 'contribute/*.rst']


# -- Options for HTML output -------------------------------------------------

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
#
html_theme = "sphinx_rtd_theme"

html_logo = 'logo.png'

html_theme_options = {
    'logo_only': True,
    'style_external_links': True,
}


html_static_path = ['_static']

html_js_files = ['version.js']

html_extra_path = ['images/donate/ppdonate.png','images/donate/ZOOM_button_small.png']
html_favicon = 'scummvm.ico'

# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".

html_css_files = ["https://cdnjs.cloudflare.com/ajax/libs/font-awesome/4.7.0/css/font-awesome.min.css"]

def setup(app):
   app.add_css_file("custom.css")

master_doc = 'index'
html_sidebars = {'**': ['localtoc.html']}

panels_add_fontawesome_latex = True

#Options for LaTex Output

latex_elements = {
    'extraclassoptions': 'openany,oneside',
    'fncychap': ' ',
    'pointsize': '11pt',
    'preamble': r'''
        \usepackage{charter}
        \usepackage[defaultsans]{lato}
        \usepackage{inconsolata}
    ''',

}

==> scummvm_2.9.1+dfsg.orig.tar.xz: scummvm-2.9.1/doc/docportal/conf.py <==
# Configuration file for the Sphinx documentation builder.
#
# This file only contains a selection of the most common options. For a full
# list see the documentation:
# https://www.sphinx-doc.org/en/master/usage/configuration.html

# -- Path setup --------------------------------------------------------------

# If extensions (or modules to document with autodoc) are in another directory,
# add these directories to sys.path here. If the directory is relative to the
# documentation root, use os.path.abspath to make it absolute, like shown here.
#
# import os
# import sys
# sys.path.insert(0, os.path.abspath('.'))


# -- Project information -----------------------------------------------------

project = 'ScummVM Documentation'
copyright = '2020-2024, ScummVM'
author = 'ScummVM'


# -- General configuration ---------------------------------------------------

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
# ones.

extensions = [

    "sphinx_rtd_theme",
    "sphinx_design",
    "sphinx_mdinclude",
]
souce_suffix = ['.rst','.md']

# Add any paths that contain templates here, relative to this directory.
templates_path = ['_templates']

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
# This pattern also affects html_static_path and html_extra_path.
exclude_patterns = ['_build', 'Thumbs.db', '.DS_Store', 'contribute/*.rst']


# -- Options for HTML output -------------------------------------------------

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
#
html_theme = "sphinx_rtd_theme"

html_logo = 'logo.png'

html_theme_options = {
    'logo_only': True,
    'style_external_links': True,
}


html_static_path = ['_static']

html_js_files = ['version.js']

html_extra_path = ['images/donate/ppdonate.png','images/donate/ZOOM_button_small.png']
html_favicon = 'scummvm.ico'

# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".

html_css_files = ["https://cdnjs.cloudflare.com/ajax/libs/font-awesome/4.7.0/css/font-awesome.min.css"]

def setup(app):
   app.add_css_file("custom.css")

master_doc = 'index'
html_sidebars = {'**': ['localtoc.html']}

#Options for LaTex Output

latex_elements = {
    'extraclassoptions': 'openany,oneside',
    'fncychap': ' ',
    'pointsize': '11pt',
    'preamble': r'''
        \usepackage{charter}
        \usepackage[defaultsans]{lato}
        \usepackage{inconsolata}
    ''',

}
